@@ -129,6 +129,7 @@ else:
 	global LR_RAMPUP_EPOCHS
 	global LR_SUSTAIN_EPOCHS
 	global LR_EXP_DEC
+	global LR_START
 	
 	import tensorflow as tf
 	if tf.__version__ == '2.2.0':
@@ -140,4 +141,5 @@ else:
 	LR_MIN = 0.00001
 	LR_RAMPUP_EPOCHS = 5
 	LR_SUSTAIN_EPOCHS = 0
-	LR_EXP_DECAY = 0.8
\ No newline at end of file
+	LR_EXP_DECAY = 0.8
+	LR_START = 0.00001
\ No newline at end of file
