@@ -41,46 +41,71 @@ def get_predictions(testTFdataset, model, output_filename):
 
 	
 ## functions for ensembling using Models
-def ensemble_model_average(models_list, testTFdataset):
+def ensemble_model_average(models_list, testTFdataset, classification_type):
+    import numpy as np
+
+    test_images_ds = testTFdataset.map(lambda image, idnum : image)
+    NUM_IMAGES = 0
+    for data in test_images_ds.unbatch():
+        NUM_IMAGES += 1
+    if classification_type == 'multiclass':
+        probs = np.average([models_list[i].predict(test_images_ds) for i in range(len(models_list))], axis = 0)
+        preds = np.argmax(probs, axis = -1)
+    elif classification_type == 'binary':
+        
+        preds = np.average([models_list[i].predict(test_images_ds) for i in range(len(models_list))], axis = 0)
+        preds = np.array([1 if i >= 0.5 else 0 for i in preds])
+        preds = np.reshape(preds, newshape = (NUM_IMAGES,) )
+    else:
+        print("Choose classification type between 'multiclass' & 'binary'...Not a valid Input.. Exiting")
+        return
+    return preds
+
+def ensemble_model_weighted(weights, models_list, testTFdataset, classification_type):
+    import numpy as np
+    probs = []
+    test_images_ds = testTFdataset.map(lambda image, idnum : image)
+    NUM_IMAGES = 0
+    for data in test_images_ds.unbatch():
+        NUM_IMAGES += 1
+    
+    if classification_type == 'binary':
+        preds = np.array(sum([models_list[i].predict(test_images_ds) * weights[i] for i in range(len(models_list))]))    
+        preds = np.array([1 if i >= 0.5 else 0 for i in preds])
+        preds = np.reshape(preds, newshape = (NUM_IMAGES,))
+        return preds
+    elif classification_type == 'multiclass':
+        
+        for model in models_list:
+            probs.append(model.predict(test_images_ds))
+
+        final_probs = None
+        for i, w in enumerate(weights):
+            final_probs = w * probs[i]
+
+        preds = np.argmax(final_probs, axis = -1)
+    
+    else:
+        print("Classification type not between 'binary' and 'multiclass'. Please choose the correct classification type...Exiting..")
+        return
+    return preds
+
+
+def ensemble_predictions(models_list,  testTFdataset, ensemble_type = 'Model Averaging', classification_type = 'mutliclass'):
 	import numpy as np
-
-	test_images_ds = testTFdataset.map(lambda image, idnum : image)
-
-	probs = np.average([models_list[i].predict(test_images_ds) for i in range(len(models_list))], axis = 0)
-	preds = np.argmax(probs, axis = -1)
-
-	return preds
-
-def ensemble_model_weighted(weights, models_list, testTFdataset):
-	
-	probs = []
-	test_images_ds = testTFdataset.map(lambda image, idnum : image)
-
-	for model in models_list:
-		probs.append(model.predict(test_images_ds))
-
-	final_probs = None
-	for i, w in enumerate(weights):
-		final_probs = w * probs[i]
-
-	preds = np.argmax(final_probs, axis = -1)	
-	return preds
-
-
-def ensemble_predictions(models_list,  testTFdataset, ensemble_type = 'Model Average'):
 	if ensemble_type == 'Model Averaging':
 		print("Computing predictions through Model Averaging")
-		preds =  ensemble_model_average(models_list, testTFdataset)
+		preds =  ensemble_model_average(models_list, testTFdataset, classification_type)
 		print("Generating output file...")
 
 		ids = testTFdataset.map(lambda image, idnum : idnum).unbatch()
 
 		NUM_TEST_IMAGES = 0
-		for data in testTFdataset:
+		for data in testTFdataset.unbatch():
 			NUM_TEST_IMAGES += 1
 
 		ids = next(iter(ids.batch(NUM_TEST_IMAGES))).numpy().astype('U')
-		np.savetxt('ensemble_model_averaging.csv', np.rec.fromarrays([ids, predictions]), fmt = ['%s', '%d'], delimiter = ',', header = 'id,label', comments = '')
+		np.savetxt('ensemble_model_averaging.csv', np.rec.fromarrays([ids, preds]), fmt = ['%s', '%d'], delimiter = ',', header = 'id,label', comments = '')
 		print("Predictions obtained with the output filename as -> ensemble_model_average")
 
 	elif ensemble_type == 'Model Weighted':
@@ -90,25 +115,24 @@ def ensemble_predictions(models_list,  testTFdataset, ensemble_type = 'Model Ave
 		weights = [float(i) for i in weights]
 
 		print("Computing predictions through Model Weighted")
-		preds =  ensemble_model_weighted(weights, models_list, testTFdataset)
+		preds =  ensemble_model_weighted(weights, models_list, testTFdataset, classification_type)
 
 		print("Generating output file...")
 
 		ids = testTFdataset.map(lambda image, idnum : idnum).unbatch()
 
 		NUM_TEST_IMAGES = 0
-		for data in testTFdataset:
+		for data in testTFdataset.unbatch():
 			NUM_TEST_IMAGES += 1
 
 		ids = next(iter(ids.batch(NUM_TEST_IMAGES))).numpy().astype('U')
-		np.savetxt('ensemble_model_weighted.csv', np.rec.fromarrays([ids, predictions]), fmt = ['%s', '%d'], delimiter = ',', header = 'id,label', comments = '')
+		np.savetxt('ensemble_model_weighted.csv', np.rec.fromarrays([ids, preds]), fmt = ['%s', '%d'], delimiter = ',', header = 'id,label', comments = '')
 		print("Predictions obtained with the output filename as -> ensemble_model_weighted.csv")
 
 
 	else:
 		print("Please choose ensemble_type between 'Model Averaging' or 'Model Weighted'")
 		return
-
 	#return preds
 
 
